@@ -138,22 +138,24 @@ def BinaryAlexNet(
     | 36.30 %        | 61.53 %        | 61 859 192 | 7.49 MB |
 
     # Arguments
-    input_shape: Optional shape tuple, to be specified if you would like to use a model
-        with an input image resolution that is not (224, 224, 3).
-        It should have exactly 3 inputs channels.
-    input_tensor: optional Keras tensor (i.e. output of `layers.Input()`) to use as
-        image input for the model.
-    weights: one of `None` (random initialization), "imagenet" (pre-training on
-        ImageNet), or the path to the weights file to be loaded.
-    include_top: whether to include the fully-connected layer at the top of the network.
-    num_classes: optional number of classes to classify images into, only to be
-        specified if `include_top` is True, and if no `weights` argument is specified.
+        input_shape: Optional shape tuple, to be specified if you would like to use a
+            model with an input image resolution that is not (224, 224, 3).
+            It should have exactly 3 inputs channels.
+        input_tensor: optional Keras tensor (i.e. output of `layers.Input()`) to use as
+            image input for the model.
+        weights: one of `None` (random initialization), "imagenet" (pre-training on
+            ImageNet), or the path to the weights file to be loaded.
+        include_top: whether to include the fully-connected layer at the top of the
+            network.
+        num_classes: optional number of classes to classify images into, only to be
+            specified if `include_top` is True, and if no `weights` argument is
+            specified.
 
     # Returns
-    A Keras model instance.
+        A Keras model instance.
 
     # Raises
-    ValueError: in case of invalid argument for `weights`, or invalid input shape.
+        ValueError: in case of invalid argument for `weights`, or invalid input shape.
     """
     return BinaryAlexNetFactory(
         input_shape=input_shape,
