@@ -1,4 +1,3 @@
-import functools
 import os
 
 import numpy as np
@@ -8,25 +7,21 @@ from tensorflow import keras
 import larq_zoo as lqz
 
 
-def keras_test(func):
-    """Function wrapper to clean up after TensorFlow tests.
-    # Arguments
-        func: test function to clean up after.
-    # Returns
-        A function wrapping the input function.
-    """
+@pytest.fixture(autouse=True)
+def cleanup(request):
+    request.addfinalizer(keras.backend.clear_session)
 
-    @functools.wraps(func)
-    def wrapper(*args, **kwargs):
-        output = func(*args, **kwargs)
-        keras.backend.clear_session()
-        return output
 
-    return wrapper
+@pytest.fixture(scope="module")
+def test_image(request):
+    file = os.path.join(os.path.dirname(__file__), "fixtures", "elephant.jpg")
+    img = keras.preprocessing.image.load_img(file)
+    img = keras.preprocessing.image.img_to_array(img)
+    img = lqz.preprocess_input(img)
+    return np.expand_dims(img, axis=0)
 
 
 def parametrize(func):
-    func = keras_test(func)
     return pytest.mark.parametrize(
         "app,last_feature_dim",
         [
@@ -49,13 +44,9 @@ def parametrize(func):
 
 
 @parametrize
-def test_prediction(app, last_feature_dim):
-    file = os.path.join(os.path.dirname(__file__), "fixtures", "elephant.jpg")
-    img = keras.preprocessing.image.load_img(file)
-    img = keras.preprocessing.image.img_to_array(img)
-    img = lqz.preprocess_input(img)
+def test_prediction(app, last_feature_dim, test_image):
     model = app(weights="imagenet")
-    preds = model.predict(np.expand_dims(img, axis=0))
+    preds = model.predict(test_image)
 
     # Test correct label is in top 3 (weak correctness test).
     names = [p[1] for p in lqz.decode_predictions(preds, top=3)[0]]
@@ -80,20 +71,7 @@ def test_keras_tensor_input(app, last_feature_dim):
 
 
 @parametrize
-def test_no_top(app, last_feature_dim):
-    model = app(weights=None, include_top=False)
-    assert model.output_shape == (None, None, None, last_feature_dim)
-
-
-@parametrize
-def test_no_top_variable_shape_1(app, last_feature_dim):
-    input_shape = (None, None, 1)
-    model = app(weights=None, include_top=False, input_shape=input_shape)
-    assert model.output_shape == (None, None, None, last_feature_dim)
-
-
-@parametrize
-def test_no_top_variable_shape_4(app, last_feature_dim):
-    input_shape = (None, None, 4)
+@pytest.mark.parametrize("input_shape", [None, (None, None, 1), (None, None, 4)])
+def test_no_top(app, last_feature_dim, input_shape):
     model = app(weights=None, include_top=False, input_shape=input_shape)
     assert model.output_shape == (None, None, None, last_feature_dim)
